cup_cost

Function cup_cost 

pub const fn cup_cost(row: u16, col: u16) -> usize
Cost of a CUP sequence for the given 0-based position. The writer drops the column when it is 0, and drops both parameters when the destination is the origin.