pub fn write_sixel<W: Write>(
w: &mut W,
p1: i32,
p2: i32,
p3: i32,
payload: &[u8],
) -> Result<()>Expand description
Frame a Sixel payload as ESC P <p1> ; <p2> [;<p3>] q <payload> ESC \.
p1 and p2 are omitted when negative, while their semicolon separator remains. p3 is emitted only when greater than zero. payload is copied verbatim between the q final byte and ST.