pub fn write_ech<W: Write>(w: &mut W, n: u16) -> Result<()>Expand description
Erase n character cells at the cursor with ECH.
n <= 1 emits ESC [ X; larger counts emit ESC [ <n> X. Erased cells are replaced with blank cells using the active rendition.