pub fn write_window_title_and_icon<W: Write>(
w: &mut W,
title: &str,
) -> Result<()>Expand description
Set the window title and icon name with ESC ] 0 ; <title> ESC \.
OSC 0 sets both the icon name and the window title. title is emitted
verbatim and the sequence uses ST (ESC \) termination.