#[repr(u8)]pub enum KittyKeyboardMode {
Set = 1,
Add = 2,
Remove = 3,
}Expand description
Operation mode used by write_set_kitty_keyboard for CSI = flags ; mode u.
Variants
Set = 1
Replace the active keyboard flags with exactly the supplied flag set; parameter value 1.
Add = 2
Add the supplied keyboard flags to the active set; parameter value 2.
Remove = 3
Remove the supplied keyboard flags from the active set; parameter value 3.